@@ -10,7 +10,7 @@ from typing import List, Iterator, Dict, Any
 from scrapy import Spider  # type: ignore
 from scrapy.linkextractors import LinkExtractor  # type: ignore
 from scrapy.crawler import CrawlerProcess, Crawler  # type: ignore
-from scrapy import signals  # type: ignore
+from scrapy import signals
 from scrapy_splash import SplashRequest, SplashJsonResponse  # type: ignore
 
 # Mapping from https://doc.qt.io/qt-5/qnetworkreply.html#NetworkError-enum
@@ -77,10 +77,10 @@ class ScrapySplashWrapperCrawler():
         def start_requests(self):
             yield SplashRequest(self.start_url, self.parse, endpoint='execute',
                                 args={'wait': 15, 'resource_timeout': 40,
-                                      'timeout': 60,
+                                      'timeout': 90,
                                       'useragent': self.useragent,
                                       'referer': self.referer,
-                                      'cookies': self.cookies,
+                                      'cookies': [{k: v for k, v in cookie.items() if v is not None} for cookie in self.cookies],
                                       'lua_source': self.script
                                       })
 
